{% extends "account/base.html" %}
{% load i18n %}
{% block head_title %}
    {% translate "Sign out" %}
{% endblock %}
{% block whitebox %}
    <form method="post" action="{% url 'account_logout' %}">
        {% csrf_token %}
        <p>{% translate "Are you sure you want to sign out?" %}</p>
        {% translate "Sign out" as signout_message %}
        {% include "account/_button.html" with text=signout_message %}
    </form>
{% endblock %}
