{% load socialaccount i18n %}
{% get_providers as socialaccount_providers %}
{% if socialaccount_providers %}
    <div class="flex items-center self-stretch justify-between pt-3 mt-3">
        <hr class="w-full">
        <span class="p-2 mb-1 text-gray-400">OR</span>
        <hr class="w-full">
    </div>
    <p class="text-xs text-center text-gray-500">{% translate "Sign in with a third party" %}</p>
    {% include "socialaccount/snippets/provider_list.html" with process="login" %}
    {% include "socialaccount/snippets/login_extra.html" %}
{% endif %}
