{% extends "account/base.html" %}
{% load i18n %}
{% block head_title %}
    {% translate "Password Reset" %}
{% endblock %}
{% block whitebox %}
    <h1 class="mb-5 text-3xl text-center">{% translate "Password Reset" %}</h1>
    <p class="mb-5 text-sm text-center">
        {% translate "Enter your user account's verified email address and we will send you a password reset link." %}
    </p>
    <form method="POST"
          action="{% url 'account_reset_password' %}"
          class="flex flex-col mt-4">
        {% include "account/_render_form.html" %}
        {% translate "Reset my password" as reset_text %}
        {% include "account/_button.html" with text=reset_text %}
    </form>
    {% include "account/_links.html" %}
{% endblock %}
