{% extends "account/base.html" %}
{% load i18n %}
{% block head_title %}
    {% trans "Changed Password" %}
{% endblock %}
{% block content %}
    <div class="flex flex-col items-center justify-center w-screen h-screen text-gray-700 bg-gray-200">
        <div class="flex flex-col items-center p-12 bg-white rounded shadow-lg">
            <h1 class="mb-5 text-3xl">{% trans "Changed Password" %}</h1>
            <p>{% trans 'Your password is now changed.' %}</p>
            {% include "account/_links.html" %}
        </div>
    </div>
{% endblock %}
